package com.cyrilmottier.android.itemviewtype;

import android.app.ListActivity;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

public class MainListActivity extends ListActivity {

	private static final int ITEM_VIEW_TYPE_VIDEO = 0;
	private static final int ITEM_VIEW_TYPE_SEPARATOR = 1;
	private static final int ITEM_VIEW_TYPE_COUNT = 2;

	private static class Video {
		public String title;
		public String description;

		public Video(String title) {
			this(title, "bla bla");
		}

		public Video(String title, String description) {
			this.title = title;
			this.description = description;
		}
	}

	private static final Object[] OBJECTS = { "Movies",
			new Video("Iron Man 2"), new Video("Adle Blanc-Sec"),
			new Video("Twilight - Chapitre 3 : hsitation"),
			new Video("Green Zone"), new Video("Shrek 4, il tait une fin"),
			new Video("L'Amour c'est mieux  deux"),
			new Video("Sex and the City 2"), new Video("Predators"),
			new Video("Inception"), "Series",
			new Video("Dr House (Docteur House)"), new Video("True Blood"),
			new Video("Smallville"), new Video("Sanctuary"),
			new Video("Desperate Housewives"),
			new Video("Spartacus: Blood and Sand"),
			new Video("Lost, les disparus"), new Video("Stargate Universe"),
			new Video("How I Met Your Mother") };

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		setListAdapter(new VideoAdapter());
	}

	private class VideoAdapter extends BaseAdapter {

		@Override
		public int getCount() {
			return OBJECTS.length;
		}

		@Override
		public Object getItem(int position) {
			return OBJECTS[position];
		}

		@Override
		public long getItemId(int position) {
			return position;
		}

		@Override
		public int getViewTypeCount() {
			return ITEM_VIEW_TYPE_COUNT;
		}

		@Override
		public int getItemViewType(int position) {
			return (OBJECTS[position] instanceof String) ? ITEM_VIEW_TYPE_SEPARATOR
					: ITEM_VIEW_TYPE_VIDEO;
		}

		@Override
		public boolean isEnabled(int position) {
			// A separator cannot be clicked !
			return getItemViewType(position) != ITEM_VIEW_TYPE_SEPARATOR;
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {

			final int type = getItemViewType(position);

			// First, let's create a new convertView if needed. You can also
			// create a ViewHolder to speed up changes if you want ;)
			if (convertView == null) {
				final LayoutInflater inflater = LayoutInflater.from(MainListActivity.this);
				final int layoutID = type == ITEM_VIEW_TYPE_SEPARATOR ? R.layout.separator_list_item : R.layout.video_list_item;
				convertView = inflater.inflate(layoutID, parent, false);
			}

			// We can now fill the list item view with the appropriate data.
			if (type == ITEM_VIEW_TYPE_SEPARATOR) {
				((TextView) convertView).setText((String) getItem(position));
			} else {
				final Video video = (Video) getItem(position);
				((TextView) convertView.findViewById(R.id.title))
						.setText(video.title);
				((TextView) convertView.findViewById(R.id.description))
						.setText(video.description);
			}

			return convertView;
		}

	}
}